==> llexec-1.1.2.tgz: package/lib/executor/index.js <==
"use strict";
var buffered_output_1 = require('../buffered-output');
var arg_tokenizer_1 = require('../arg-tokenizer');
var childProcess = require('child_process');
var colors = require('colors');
var Executor = (function () {
    function Executor(lineWrapper) {
        this.lineWrapper = lineWrapper;
        this.taskList = [];
        this._maxCmdLength = 0;
        this._runningProcs = [];
    }
    Executor.prototype._run = function (task, taskIndex, resolve, reject) {
        var _this = this;
        var _a = arg_tokenizer_1.tokenize(task.command), command = _a[0], args = _a.slice(1);
        var stdoutBuf = null;
        var stderrBuf = null;
        var child = childProcess.spawn('bash', ['-c', task.command]);
        child.on('exit', function (code) {
            // flush the buffers
            stdoutBuf.done();
            stderrBuf.done();
            // resolve promise with the exit code
            if (code > 0) {
                // otherwise bubble the error up
                _this.killall();
                reject({
                    killed: child['killed'],
                    command: task.command
                });
            }
            else {
                resolve(true);
            }
        });
        this._runningProcs[taskIndex] = child;
        var taskInfo = {
            task: task,
            commandName: command,
            argList: args,
            argStr: args.join(' '),
            allTasks: this.taskList,
            taskIndex: taskIndex
        };
        stdoutBuf = new buffered_output_1.BufferedOutput(child.stdout, function (line) {
            if (!_this.lineWrapper) {
                return line;
            }
            return _this.lineWrapper(taskInfo, line);
        });
        stderrBuf = new buffered_output_1.BufferedOutput(child.stderr, function (line) {
            var lineWrapper = _this.lineWrapper || (function (ti, l) { return l; });
            return colors.bgRed(lineWrapper(taskInfo, line));
        });
    };
    Executor.prototype._runTask = function (task, index) {
        var _this = this;
        this.taskList.push(task);
        if (task.command.length > this._maxCmdLength) {
            this._maxCmdLength = task.command.length;
        }
        return new Promise(function (resolve, reject) {
            _this._run(task, index, resolve, reject);
        });
    };
    Executor.prototype.killall = function () {
        this._runningProcs.forEach(function (proc) { return proc && proc.kill(); });
    };
    Executor.prototype.run = function (tasks) {
        var promiseList = tasks.map(this._runTask.bind(this));
        return Promise.all(promiseList).catch(function () {
            var results = Array.prototype.slice.call(arguments, 0);
            var failedJobs = results.filter(function (r) { return r && !r.killed; });
            // rethrow the error so the promise rejects
            return Promise.reject(failedJobs);
        });
    };
    return Executor;
}());
exports.Executor = Executor;

==> llexec-1.1.3.tgz: package/lib/executor/index.js <==
"use strict";
var buffered_output_1 = require('../buffered-output');
var arg_tokenizer_1 = require('../arg-tokenizer');
var childProcess = require('child_process');
var colors = require('colors');
var Executor = (function () {
    function Executor(lineWrapper) {
        this.lineWrapper = lineWrapper;
        this.taskList = [];
        this._maxCmdLength = 0;
        this._runningProcs = [];
    }
    Executor.prototype._run = function (task, taskIndex, resolve, reject) {
        var _this = this;
        var _a = arg_tokenizer_1.tokenize(task.command), command = _a[0], args = _a.slice(1);
        var stdoutBuf = null;
        var stderrBuf = null;
        var child = childProcess.spawn('bash', ['-c', task.command]);
        child.on('close', function (code) {
            // flush the buffers
            stdoutBuf.done();
            stderrBuf.done();
            // resolve promise with the exit code
            if (code > 0) {
                // otherwise bubble the error up
                _this.killall();
                reject({
                    killed: child['killed'],
                    command: task.command
                });
            }
            else {
                resolve(true);
            }
        });
        this._runningProcs[taskIndex] = child;
        var taskInfo = {
            task: task,
            commandName: command,
            argList: args,
            argStr: args.join(' '),
            allTasks: this.taskList,
            taskIndex: taskIndex
        };
        stdoutBuf = new buffered_output_1.BufferedOutput(child.stdout, function (line) {
            if (!_this.lineWrapper) {
                return line;
            }
            return _this.lineWrapper(taskInfo, line);
        });
        stderrBuf = new buffered_output_1.BufferedOutput(child.stderr, function (line) {
            var lineWrapper = _this.lineWrapper || (function (ti, l) { return l; });
            return lineWrapper(taskInfo, colors.bgRed(colors.white(line)));
        });
    };
    Executor.prototype._runTask = function (task, index) {
        var _this = this;
        this.taskList.push(task);
        if (task.command.length > this._maxCmdLength) {
            this._maxCmdLength = task.command.length;
        }
        return new Promise(function (resolve, reject) {
            _this._run(task, index, resolve, reject);
        });
    };
    Executor.prototype.killall = function () {
        this._runningProcs.forEach(function (proc) { return proc && proc.kill(); });
    };
    Executor.prototype.run = function (tasks) {
        var promiseList = tasks.map(this._runTask.bind(this));
        return Promise.all(promiseList).catch(function () {
            var results = Array.prototype.slice.call(arguments, 0);
            var failedJobs = results.filter(function (r) { return r && !r.killed; });
            // rethrow the error so the promise rejects
            return Promise.reject(failedJobs);
        });
    };
    return Executor;
}());
exports.Executor = Executor;
